#By Talia Y. Moore May 7, 2024
#Analyses for tail data for the paper
#Jointed tails enhance control of three-dimensional body rotation
#By X. Fu, B. Zhang, C.J. Weber, K.L. Cooper, R. Vasudevan, T.Y. Moore

rm(list=ls())

#########################
#make anova table for uniform links (Figure 3a, Table 2a)
#########################
unif<-read.csv("uniform_1-6_link.csv",header=F)
head(unif)

err<-c(unif$V1,unif$V2,unif$V3,unif$V4,unif$V5,unif$V6)
utab<-NULL
utab$err<-err
utab$link<-c(rep("l1",dim(unif)[1]),rep("l2",dim(unif)[1]),rep("l3",dim(unif)[1]),
             rep("l4",dim(unif)[1]),rep("l5",dim(unif)[1]),rep("l6",dim(unif)[1]))
utab$link<-as.factor(utab$link)
utab$err<-as.numeric(utab$err)
unifanov<-aov(err~link,data=utab)

TukeyHSD(unifanov)

dim(unif)
DF.3a<-99-5

#########################
#make anova table for tail tip velocities (Figure 3b, Table 2b)
#########################
unif<-read.csv("tipvel_uniform_1-6_link.csv",header=F)
head(unif)

err<-c(unif$V1,unif$V2,unif$V3,unif$V4,unif$V5,unif$V6)
utab<-NULL
utab$err<-err
utab$link<-c(rep("l1",dim(unif)[1]),rep("l2",dim(unif)[1]),rep("l3",dim(unif)[1]),
             rep("l4",dim(unif)[1]),rep("l5",dim(unif)[1]),rep("l6",dim(unif)[1]))
utab$link<-as.factor(utab$link)
utab$err<-as.numeric(utab$err)
summary(utab)
unifanov<-aov(err~link,data=utab)
summary(unifanov)

TukeyHSD(unifanov)
DF.3b<-99-5
#load tail data
vert<-read.csv("vertbyc1.csv",header=T,row.names=1)

#########################
#plot all tails (Figure 5b)
#########################
pdf("alltailsCB.pdf",width=8,height=4)
plot(seq(1:dim(vert)[1]),vert[,1],type="l",ylim=c(0,6),col="white",ylab="Vertebra length / Cd1",xlab="Vertebra number",xlim=c(0,45))

for(i in 2:dim(vert)[2]){
  
}
#Inertia #66c2a5
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Dipodomys.merriami")],type="l",col="#66c2a5")
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Jaculus.jaculus")],type="l",col="#66c2a5")
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Dipodomys.agilis")],type="l",col="#66c2a5")
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Dipodomys.simulans")],type="l",col="#66c2a5")
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Dipodomys.stephensi")],type="l",col="#66c2a5")
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Pygathrix.nemaeus")],type="l",col="#66c2a5")
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Otolemur.crassicaudatus")],type="l",col="#66c2a5")
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Saimiri.oerstedi")],type="l",col="#66c2a5")
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Callithrix.geoffryi")],type="l",col="#66c2a5")
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Leontideus.rosalia")],type="l",col="#66c2a5")
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Bassaricyon.alleni")],type="l",col="#66c2a5")
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Varecia.variegata.1")],type="l",col="#66c2a5")

#mousy e5c494
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Perognathus.fallax")],type="l",col="#e78ac3") #
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Peromyscus.californicus")],type="l",col="#e78ac3") #
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Rattus.rattus")],type="l",col="#e78ac3") #
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Sorex.trowbridgii")],type="l",col="#e78ac3") #
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Crocidura.cyanea")],type="l",col="#e78ac3") #
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Sorex.palustris")],type="l",col="#e78ac3") #
lines(seq(1:dim(vert)[1]),vert[,which(colnames(vert)=="Mus.musculus")],type="l",col="#e78ac3") #

legend("topright",legend=c("Inertial Maneuvering", "Mouse-like"), lty="solid",col=c("#66c2a5","#e78ac3"))
dev.off()

#Find maximum difference between neighboring points 
vert[34,]<-vert[6,]-vert[5,]
vert[35,]<-vert[5,]-vert[4,]
vert[36,]<-vert[4,]-vert[3,]
vert[37,]<-vert[3,]-vert[2,]
vert[38,]<-vert[2,]-vert[1,]
for (i in 1:dim(vert)[2]){
  vert[39,i]<-max(vert[34:38,i])
}
vert[40,]<-c("IM",	"IM",	"IM",	"IM",	"IM",	"IM",	"MO",	"MO",
             "MO",	"MO",	"MO",	"IM",	"MO",	"IM",	"IM",	"IM",
             "IM",	"IM",	"MO")

slop<-NULL
slop$slop<-as.numeric(vert[39,])
slop$fxn<-as.factor(c("IM",	"IM",	"IM",	"IM",	"IM",	"IM",	"MO",	"MO",
                      "MO",	"MO",	"MO",	"IM",	"MO",	"IM",	"IM",	"IM",
                      "IM",	"IM",	"MO"))

#test for differences between the functional groups in max pairwise slope
test<-t.test(slop~fxn,data=slop)

numb.ims<-c(28, #callithrix
            25, #otolemur
            28, #leontoditus
            23, #pygathrix
            30, #saimiri
            30, #dip.m
            28, #jac
            31, #dip sim
            32, #dip ste
            31, #dip.age
            28, #bass
            29 #var
)

numb.mos<-c( 
  26, #per fall
  33, # peromyscus cal
  33, #rattus
  16, #crocidura
  19, #sorex
  31, #mus
  17 #sorex
)

mean(numb.ims)
mean(numb.mos)
sd(numb.ims)
sd(numb.mos)

#########################
# t tests for error between uniform and variable (Figure 6a)
#########################
link2<-read.csv("uniform_vs_varied_2_link.csv",header=T)
link3<-read.csv("uniform_vs_varied_3_link.csv",header=T)
link4<-read.csv("uniform_vs_varied_4_link.csv",header=T)
test2<-t.test(link2$uni,link2$var,paired=T)
test2
test3<-t.test(link3$uni,link3$var,paired=T)
test3
test4<-t.test(link4$uni,link4$var,paired=T)
test4

# t tests for tip velocities between uniform and variable (Figure 6b)
unif<-read.csv("tipvel_uniform_1-6_link.csv",header=F)
colnames(unif)<-c("link1","link2","link3","link4","link5","link6")
vari<-read.csv("tipvel_varied_2-4_link.csv",header=F)
colnames(vari)<-c("link2","link3","link4")

test.2.links<-t.test(unif$link2,vari$link2,paired=T)
test.3.links<-t.test(unif$link3,vari$link3,paired=T)
test.4.links<-t.test(unif$link4,vari$link4,paired=T)
test.2.links
test.3.links
test.4.links

#########################
#do t test on joint control effort (Figure 7)
#########################
link4.1<-read.csv("joint_ctrl_effort_comp/four-link_tail/joint1.csv",header=F)
link4.2<-read.csv("joint_ctrl_effort_comp/four-link_tail/joint1.csv",header=F)
link4.3<-read.csv("joint_ctrl_effort_comp/four-link_tail/joint1.csv",header=F)
link4.4<-read.csv("joint_ctrl_effort_comp/four-link_tail/joint1.csv",header=F)

link3.1<-read.csv("joint_ctrl_effort_comp/three-link_tail/joint1.csv",header=F)
link3.2<-read.csv("joint_ctrl_effort_comp/three-link_tail/joint2.csv",header=F)
link3.3<-read.csv("joint_ctrl_effort_comp/three-link_tail/joint3.csv",header=F)

link2.1<-read.csv("joint_ctrl_effort_comp/two-link_tail/joint1.csv",header=F)
link2.2<-read.csv("joint_ctrl_effort_comp/two-link_tail/joint2.csv",header=F)
test4.1<-t.test(link4.1$V1,link4.1$V2,paired=T)
test4.2<-t.test(link4.2$V1,link4.2$V2,paired=T)
test4.3<-t.test(link4.3$V1,link4.3$V2,paired=T)
test4.4<-t.test(link4.4$V1,link4.4$V2,paired=T)
test3.1<-t.test(link3.1$V1,link3.1$V2,paired=T)
test3.2<-t.test(link3.2$V1,link3.2$V2,paired=T)
test3.3<-t.test(link3.3$V1,link3.3$V2,paired=T)
test2.1<-t.test(link2.1$V1,link2.1$V2,paired=T)
test2.2<-t.test(link2.2$V1,link2.2$V2,paired=T)

test4.1
test4.2
test4.3
test4.4
test3.1
test3.2
test3.3
test2.1
test2.2


